@@ -9,22 +9,11 @@
  * file that was distributed with this source code.
  */
 
-require_once __DIR__.'/../../../../ClassLoader/ClassLoader.php';
+require_once __DIR__.'/../../vendor/autoload.php';
 
-use Symfony\Component\ClassLoader\ClassLoader;
 use Symfony\Component\Finder\Finder;
 use Symfony\Component\Security\Acl\Dbal\Schema;
 
-$loader = new ClassLoader();
-$loader->addPrefixes([
-    'Symfony' => __DIR__.'/../../../../../..',
-    'Doctrine\\Common' => __DIR__.'/../../../../../../../vendor/doctrine-common/lib',
-    'Doctrine\\DBAL\\Migrations' => __DIR__.'/../../../../../../../vendor/doctrine-migrations/lib',
-    'Doctrine\\DBAL' => __DIR__.'/../../../../../../../vendor/doctrine/dbal/lib',
-    'Doctrine' => __DIR__.'/../../../../../../../vendor/doctrine/lib',
-]);
-$loader->register();
-
 $schema = new Schema([
     'class_table_name' => 'acl_classes',
     'entry_table_name' => 'acl_entries',
@@ -35,9 +24,8 @@ $schema = new Schema([
 
 $reflection = new ReflectionClass('Doctrine\\DBAL\\Platforms\\AbstractPlatform');
 $finder = new Finder();
-$finder->name('*Platform.php')->in(\dirname($reflection->getFileName()));
+$finder->name('*Platform.php')->in(dirname($reflection->getFileName()));
 foreach ($finder as $file) {
-    require_once $file->getPathName();
     $className = 'Doctrine\\DBAL\\Platforms\\'.$file->getBasename('.php');
 
     $reflection = new ReflectionClass($className);
