@@ -11,9 +11,12 @@
 
 namespace Symfony\Component\Security\Acl\Tests\Domain;
 
+use PHPUnit\Framework\TestCase;
 use Symfony\Component\Security\Acl\Domain\FieldEntry;
+use Symfony\Component\Security\Acl\Model\SecurityIdentityInterface;
+use Symfony\Component\Security\Acl\Tests\Fixtures\SerializableAclInterface;
 
-class FieldEntryTest extends \PHPUnit\Framework\TestCase
+class FieldEntryTest extends TestCase
 {
     public function testConstructor()
     {
@@ -30,7 +33,7 @@ class FieldEntryTest extends \PHPUnit\Framework\TestCase
         $uAce = unserialize($serialized);
 
         $this->assertNull($uAce->getAcl());
-        $this->assertInstanceOf('Symfony\Component\Security\Acl\Model\SecurityIdentityInterface', $uAce->getSecurityIdentity());
+        $this->assertInstanceOf(SecurityIdentityInterface::class, $uAce->getSecurityIdentity());
         $this->assertEquals($ace->getId(), $uAce->getId());
         $this->assertEquals($ace->getField(), $uAce->getField());
         $this->assertEquals($ace->getMask(), $uAce->getMask());
@@ -40,6 +43,27 @@ class FieldEntryTest extends \PHPUnit\Framework\TestCase
         $this->assertEquals($ace->isAuditFailure(), $uAce->isAuditFailure());
     }
 
+    public function testSerializeUnserializeMoreAceWithSameSecurityIdentity()
+    {
+        $sid = $this->getSid();
+
+        $aceFirst = $this->getAce(null, $sid);
+        $aceSecond = $this->getAce(null, $sid);
+
+        // as used in DoctrineAclCache::putInCache (line 142)
+        $serialized = serialize([[
+            'fieldOne' => [$aceFirst],
+            'fieldTwo' => [$aceSecond],
+        ]]);
+
+        $unserialized = unserialize($serialized);
+        $uAceFirst = $unserialized[0]['fieldOne'][0];
+        $uAceSecond = $unserialized[0]['fieldTwo'][0];
+
+        $this->assertInstanceOf(SecurityIdentityInterface::class, $uAceFirst->getSecurityIdentity());
+        $this->assertInstanceOf(SecurityIdentityInterface::class, $uAceSecond->getSecurityIdentity());
+    }
+
     protected function getAce($acl = null, $sid = null)
     {
         if (null === $acl) {
@@ -64,11 +88,11 @@ class FieldEntryTest extends \PHPUnit\Framework\TestCase
 
     protected function getAcl()
     {
-        return $this->createMock('Symfony\Component\Security\Acl\Model\AclInterface');
+        return $this->createMock(SerializableAclInterface::class);
     }
 
     protected function getSid()
     {
-        return $this->createMock('Symfony\Component\Security\Acl\Model\SecurityIdentityInterface');
+        return $this->createMock(SecurityIdentityInterface::class);
     }
 }
