@@ -11,11 +11,12 @@
 
 namespace Symfony\Component\Security\Acl\Tests\Domain;
 
+use PHPUnit\Framework\TestCase;
 use Symfony\Component\Security\Acl\Domain\RoleSecurityIdentity;
 use Symfony\Component\Security\Acl\Domain\UserSecurityIdentity;
-use Symfony\Component\Security\Core\Role\Role;
+use Symfony\Component\Security\Acl\Model\SecurityIdentityInterface;
 
-class RoleSecurityIdentityTest extends \PHPUnit\Framework\TestCase
+class RoleSecurityIdentityTest extends TestCase
 {
     public function testConstructor()
     {
@@ -24,17 +25,10 @@ class RoleSecurityIdentityTest extends \PHPUnit\Framework\TestCase
         $this->assertEquals('ROLE_FOO', $id->getRole());
     }
 
-    public function testConstructorWithRoleInstance()
-    {
-        $id = new RoleSecurityIdentity(new Role('ROLE_FOO'));
-
-        $this->assertEquals('ROLE_FOO', $id->getRole());
-    }
-
     /**
      * @dataProvider getCompareData
      */
-    public function testEquals($id1, $id2, $equal)
+    public function testEquals(RoleSecurityIdentity $id1, SecurityIdentityInterface $id2, bool $equal)
     {
         if ($equal) {
             $this->assertTrue($id1->equals($id2));
@@ -43,11 +37,10 @@ class RoleSecurityIdentityTest extends \PHPUnit\Framework\TestCase
         }
     }
 
-    public function getCompareData()
+    public function getCompareData(): array
     {
         return [
             [new RoleSecurityIdentity('ROLE_FOO'), new RoleSecurityIdentity('ROLE_FOO'), true],
-            [new RoleSecurityIdentity('ROLE_FOO'), new RoleSecurityIdentity(new Role('ROLE_FOO')), true],
             [new RoleSecurityIdentity('ROLE_USER'), new RoleSecurityIdentity('ROLE_FOO'), false],
             [new RoleSecurityIdentity('ROLE_FOO'), new UserSecurityIdentity('ROLE_FOO', 'Foo'), false],
         ];
