@@ -284,7 +284,7 @@ class CustomUserImpl implements UserInterface
         return [];
     }
 
-    public function eraseCredentials()
+    public function eraseCredentials(): void
     {
     }
 
